@@ -11,13 +11,19 @@ dat <- as.data.frame(cbind(wage, X))
 dat$x4 <- as.factor(dat$x4)
 colnames(dat)[1] <- "wage"
 wgt <- rexp(n, 0.5)
+res <- linear_projection(wage, X.list = list("x1", c("x2", "x3", "x4")),
+                         data = dat, wgt= wgt)
 
-test_that("linear_projection returns valid output", {
-  res <- linear_projection(wage, X.list = list("x1", c("x2", "x3", "x4")),
-                           data = dat, wgt= wgt)
+test_that("linear_projection returns valid rows", {
   y <- apply(res, 1, sum)
   wage <- standardize(dat$wage , wgt)
   diff <- y - wage
   #y should be equal to wage up to a constant
   expect_true(wtd_var(diff, wgt) < 10^-10)
+})
+
+test_that("linear_projection returns valid columns", {
+  mean_col <- apply(res, 2, wtd.mean, weights = wgt)
+  #y should be equal to wage up to a constant
+  expect_true(all(abs(mean_col) < 10^-10))
 })
\ No newline at end of file
